@@ -32,7 +32,6 @@
 #include "gdkprivate-directfb.h"
 #include "gdkscreen.h"
 #include "gdkdisplaymanager.h"
-#include "gdkalias.h"
 
 
 extern void _gdk_visual_init            (void);
@@ -40,7 +39,6 @@ extern void _gdk_events_init            (void);
 extern void _gdk_input_init             (void);
 extern void _gdk_dnd_init               (void);
 extern void _gdk_windowing_window_init  (void);
-extern void _gdk_windowing_image_init   (void);
 extern void _gdk_directfb_keyboard_init (void);
 
 static gboolean   gdk_directfb_argb_font           = FALSE;
@@ -66,15 +64,12 @@ GdkDisplay * gdk_display_open (const gchar *display_name)
   IDirectFBInputDevice   *keyboard;
   DFBResult               ret;
 
-  int    argc = 0;
-  char **argv = NULL;
-
   if (_gdk_display)
     {
       return GDK_DISPLAY_OBJECT(_gdk_display); /* single display only */
     }
 
-  ret = DirectFBInit (&argc,&argv);
+  ret = DirectFBInit (NULL, NULL);
   if (ret != DFB_OK)
     {
       DirectFBError ("gdk_display_open: DirectFBInit", ret);
@@ -96,22 +91,24 @@ GdkDisplay * gdk_display_open (const gchar *display_name)
     {
       DirectFBError ("gdk_display_open: GetDisplayLayer", ret);
       directfb->Release (directfb);
-	  directfb = NULL;
+      _gdk_display->directfb = NULL;
       return NULL;
     }
 
 
-  ret=directfb->GetInputDevice (directfb, DIDID_KEYBOARD, &keyboard);
-
-  if (ret != DFB_OK){
+  ret = directfb->GetInputDevice (directfb, DIDID_KEYBOARD, &keyboard);
+  if (ret != DFB_OK)
+    {
       DirectFBError ("gdk_display_open: GetInputDevice", ret);
-   	return NULL;
-  }
+      directfb->Release (directfb);
+      _gdk_display->directfb = NULL;
+      return NULL;
+    }
 
   _gdk_display->layer=layer;
   _gdk_display->keyboard=keyboard;
 
-    _gdk_directfb_keyboard_init ();
+  _gdk_directfb_keyboard_init ();
 
   _gdk_screen = g_object_new (GDK_TYPE_SCREEN, NULL);
 
@@ -121,10 +118,10 @@ GdkDisplay * gdk_display_open (const gchar *display_name)
   gdk_screen_set_default_colormap (_gdk_screen,
                                    gdk_screen_get_system_colormap (_gdk_screen));  _gdk_windowing_image_init ();
 
+  _gdk_events_init ();
   _gdk_input_init ();
   _gdk_dnd_init ();
 
-  _gdk_events_init ();
   layer->EnableCursor (layer, 1);
 
   g_signal_emit_by_name (gdk_display_manager_get (),
@@ -541,8 +538,3 @@ gdk_display_supports_composite (GdkDisplay *display)
 {
     return FALSE;
 }
-
-
-#define __GDK_DISPLAY_X11_C__
-#include "gdkaliasdef.c"
-
