@@ -43,7 +43,6 @@
 #include "gdkinternals.h"
 
 #include "gdkpixmap.h"
-#include "gdkalias.h"
 
 
 static void gdk_pixmap_impl_directfb_init       (GdkPixmapImplDirectFB      *pixmap);
@@ -195,111 +194,6 @@ _gdk_pixmap_new (GdkDrawable *drawable,
   return pixmap;
 }
 
-GdkPixmap *
-_gdk_bitmap_create_from_data (GdkDrawable   *drawable,
-                              const gchar *data,
-                              gint         width,
-                              gint         height)
-{
-  GdkPixmap *pixmap;
-
-  g_return_val_if_fail (drawable == NULL || GDK_IS_DRAWABLE (drawable), NULL);
-  g_return_val_if_fail (data != NULL, NULL);
-  g_return_val_if_fail (width > 0 && height > 0, NULL);
-
-  GDK_NOTE (MISC, g_print ("gdk_bitmap_create_from_data: %dx%d\n",
-                           width, height));
-
-  pixmap = gdk_pixmap_new (drawable, width, height, 1);
-
-#define GET_PIXEL(data,pixel) \
-  ((data[(pixel / 8)] & (0x1 << ((pixel) % 8))) >> ((pixel) % 8))
-
-  if (pixmap)
-    {
-      guchar *dst;
-      gint    pitch;
-
-      IDirectFBSurface *surface;
-
-      surface = GDK_DRAWABLE_IMPL_DIRECTFB (GDK_PIXMAP_OBJECT (pixmap)->impl)->surface;
-
-      if (surface->Lock( surface, DSLF_WRITE, (void**)(&dst), &pitch ) == DFB_OK)
-        {
-          gint i, j;
-
-          for (i = 0; i < height; i++)
-            {
-	      for (j = 0; j < width; j++)
-		{
-		  dst[j] = GET_PIXEL (data, j) * 255;
-		}
-
-              data += (width + 7) / 8;
-	      dst += pitch;
-            }
-
-          surface->Unlock( surface );
-        }
-    }
-
-#undef GET_PIXEL
-
-  return pixmap;
-}
-
-GdkPixmap*
-_gdk_pixmap_create_from_data (GdkDrawable   *drawable,
-                              const gchar *data,
-                              gint         width,
-                              gint         height,
-                              gint         depth,
-                              const GdkColor    *fg,
-                              const GdkColor    *bg)
-{
-  GdkPixmap *pixmap;
-
-  g_return_val_if_fail (drawable == NULL || GDK_IS_DRAWABLE (drawable), NULL);
-  g_return_val_if_fail (data != NULL, NULL);
-  g_return_val_if_fail (drawable != NULL || depth > 0, NULL);
-  g_return_val_if_fail (width > 0 && height > 0, NULL);
-
-  GDK_NOTE (MISC, g_print ("gdk_pixmap_create_from_data: %dx%dx%d\n",
-                           width, height, depth));
-
-  pixmap = gdk_pixmap_new (drawable, width, height, depth);
-
-  if (pixmap)
-    {
-      IDirectFBSurface *surface;
-      gchar            *dst;
-      gint              pitch;
-      gint              src_pitch;
-
-      depth = gdk_drawable_get_depth (pixmap);
-      src_pitch = width * ((depth + 7) / 8);
-
-      surface = GDK_DRAWABLE_IMPL_DIRECTFB (GDK_PIXMAP_OBJECT (pixmap)->impl)->surface;
-
-      if (surface->Lock( surface,
-                         DSLF_WRITE, (void**)(&dst), &pitch ) == DFB_OK)
-        {
-          gint i;
-
-          for (i = 0; i < height; i++)
-            {
-              memcpy (dst, data, src_pitch);
-              dst += pitch;
-              data += src_pitch;
-            }
-
-          surface->Unlock( surface );
-        }
-    }
-
-  return pixmap;
-}
-
 GdkPixmap*
 gdk_pixmap_foreign_new (GdkNativeWindow anid)
 {
@@ -336,6 +230,3 @@ GdkPixmap* gdk_pixmap_lookup_for_display (GdkDisplay *display,GdkNativeWindow an
 {
   return gdk_pixmap_lookup (anid);
 }
-
-#define __GDK_PIXMAP_X11_C__
-#include "gdkaliasdef.c"
