@@ -38,7 +38,6 @@
 #include "gdkprivate-directfb.h"
 
 #include "gdkinternals.h"
-#include "gdkalias.h"
 
 
 static GdkColormap *default_colormap = NULL;
@@ -86,6 +85,14 @@ gdk_screen_get_n_monitors (GdkScreen *screen)
   return 1;
 }
 
+gint
+gdk_screen_get_primary_monitor (GdkScreen *screen)
+{
+  g_return_val_if_fail (GDK_IS_SCREEN (screen), 0);
+
+  return 0;
+}
+
 void
 gdk_screen_get_monitor_geometry (GdkScreen    *screen,
 				 gint          num_monitor,
@@ -100,6 +107,27 @@ gdk_screen_get_monitor_geometry (GdkScreen    *screen,
   dest->height = gdk_screen_height ();
 }
 
+gint
+gdk_screen_get_monitor_width_mm (GdkScreen *screen,
+                                 gint       monitor_num)
+{
+  return gdk_screen_get_width_mm (screen);
+}
+
+gint
+gdk_screen_get_monitor_height_mm (GdkScreen *screen,
+                                  gint       monitor_num)
+{
+  return gdk_screen_get_height_mm (screen);
+}
+
+gchar *
+gdk_screen_get_monitor_plug_name (GdkScreen *screen,
+                                  gint       monitor_num)
+{
+  return g_strdup ("DirectFB");
+}
+
 gint
 gdk_screen_get_number (GdkScreen *screen)
 {
@@ -218,6 +246,3 @@ gdk_screen_is_composited (GdkScreen *screen)
    g_return_val_if_fail (GDK_IS_SCREEN (screen), FALSE);
    return FALSE;
 } 
-
-#define __GDK_SCREEN_X11_C__
-#include "gdkaliasdef.c"
