@@ -41,17 +41,12 @@
 #include <gdk/gdkdrawable.h>
 #include <gdk/gdkenumtypes.h>
 #include <gdk/gdkevents.h>
-#include <gdk/gdkfont.h>
-#include <gdk/gdkgc.h>
-#include <gdk/gdkimage.h>
 #include <gdk/gdkinput.h>
 #include <gdk/gdkkeys.h>
 #include <gdk/gdkpango.h>
 #include <gdk/gdkpixbuf.h>
 #include <gdk/gdkpixmap.h>
 #include <gdk/gdkproperty.h>
-#include <gdk/gdkregion.h>
-#include <gdk/gdkrgb.h>
 #include <gdk/gdkscreen.h>
 #include <gdk/gdkselection.h>
 #include <gdk/gdkspawn.h>
@@ -91,22 +86,6 @@ gint      gdk_error_trap_pop            (void);
 gchar*	                  gdk_get_display		(void);
 G_CONST_RETURN gchar*	  gdk_get_display_arg_name	(void);
 
-#if !defined (GDK_DISABLE_DEPRECATED) || defined (GTK_COMPILATION)
-/* Used by gtk_input_add_full () */
-gint gdk_input_add_full	  (gint		     source,
-			   GdkInputCondition condition,
-			   GdkInputFunction  function,
-			   gpointer	     data,
-			   GDestroyNotify    destroy);
-#endif /* !GDK_DISABLE_DEPRECATED || GTK_COMPILATION */
-#ifndef GDK_DISABLE_DEPRECATED
-gint gdk_input_add	  (gint		     source,
-			   GdkInputCondition condition,
-			   GdkInputFunction  function,
-			   gpointer	     data);
-void gdk_input_remove	  (gint		     tag);
-#endif /* GDK_DISABLE_DEPRECATED */
-
 #ifndef GDK_MULTIDEVICE_SAFE
 GdkGrabStatus gdk_pointer_grab       (GdkWindow    *window,
 				      gboolean      owner_events,
@@ -155,15 +134,6 @@ GType gdk_rectangle_get_type (void) G_GNUC_CONST;
 
 #define GDK_TYPE_RECTANGLE (gdk_rectangle_get_type ())
 
-/* Conversion functions between wide char and multibyte strings. 
- */
-#ifndef GDK_DISABLE_DEPRECATED
-gchar     *gdk_wcstombs          (const GdkWChar   *src);
-gint       gdk_mbstowcs          (GdkWChar         *dest,
-				  const gchar      *src,
-				  gint              dest_max);
-#endif
-
 /* Miscellaneous */
 #ifndef GDK_MULTIHEAD_SAFE
 gboolean gdk_event_send_client_message      (GdkEvent       *event,
