@@ -433,164 +433,6 @@ gdk_owner_change_get_type (void)
     return etype;
 }
 
-/* enumerations from "gdkgc.h" */
-GType
-gdk_cap_style_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_CAP_NOT_LAST, "GDK_CAP_NOT_LAST", "not-last" },
-            { GDK_CAP_BUTT, "GDK_CAP_BUTT", "butt" },
-            { GDK_CAP_ROUND, "GDK_CAP_ROUND", "round" },
-            { GDK_CAP_PROJECTING, "GDK_CAP_PROJECTING", "projecting" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkCapStyle"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_fill_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_SOLID, "GDK_SOLID", "solid" },
-            { GDK_TILED, "GDK_TILED", "tiled" },
-            { GDK_STIPPLED, "GDK_STIPPLED", "stippled" },
-            { GDK_OPAQUE_STIPPLED, "GDK_OPAQUE_STIPPLED", "opaque-stippled" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkFill"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_function_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_COPY, "GDK_COPY", "copy" },
-            { GDK_INVERT, "GDK_INVERT", "invert" },
-            { GDK_XOR, "GDK_XOR", "xor" },
-            { GDK_CLEAR, "GDK_CLEAR", "clear" },
-            { GDK_AND, "GDK_AND", "and" },
-            { GDK_AND_REVERSE, "GDK_AND_REVERSE", "and-reverse" },
-            { GDK_AND_INVERT, "GDK_AND_INVERT", "and-invert" },
-            { GDK_NOOP, "GDK_NOOP", "noop" },
-            { GDK_OR, "GDK_OR", "or" },
-            { GDK_EQUIV, "GDK_EQUIV", "equiv" },
-            { GDK_OR_REVERSE, "GDK_OR_REVERSE", "or-reverse" },
-            { GDK_COPY_INVERT, "GDK_COPY_INVERT", "copy-invert" },
-            { GDK_OR_INVERT, "GDK_OR_INVERT", "or-invert" },
-            { GDK_NAND, "GDK_NAND", "nand" },
-            { GDK_NOR, "GDK_NOR", "nor" },
-            { GDK_SET, "GDK_SET", "set" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkFunction"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_join_style_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_JOIN_MITER, "GDK_JOIN_MITER", "miter" },
-            { GDK_JOIN_ROUND, "GDK_JOIN_ROUND", "round" },
-            { GDK_JOIN_BEVEL, "GDK_JOIN_BEVEL", "bevel" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkJoinStyle"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_line_style_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_LINE_SOLID, "GDK_LINE_SOLID", "solid" },
-            { GDK_LINE_ON_OFF_DASH, "GDK_LINE_ON_OFF_DASH", "on-off-dash" },
-            { GDK_LINE_DOUBLE_DASH, "GDK_LINE_DOUBLE_DASH", "double-dash" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkLineStyle"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_subwindow_mode_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_CLIP_BY_CHILDREN, "GDK_CLIP_BY_CHILDREN", "clip-by-children" },
-            { GDK_INCLUDE_INFERIORS, "GDK_INCLUDE_INFERIORS", "include-inferiors" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkSubwindowMode"), values);
-    }
-    return etype;
-}
-
-GType
-gdk_gc_values_mask_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GFlagsValue values[] = {
-            { GDK_GC_FOREGROUND, "GDK_GC_FOREGROUND", "foreground" },
-            { GDK_GC_BACKGROUND, "GDK_GC_BACKGROUND", "background" },
-            { GDK_GC_FUNCTION, "GDK_GC_FUNCTION", "function" },
-            { GDK_GC_FILL, "GDK_GC_FILL", "fill" },
-            { GDK_GC_TILE, "GDK_GC_TILE", "tile" },
-            { GDK_GC_STIPPLE, "GDK_GC_STIPPLE", "stipple" },
-            { GDK_GC_CLIP_MASK, "GDK_GC_CLIP_MASK", "clip-mask" },
-            { GDK_GC_SUBWINDOW, "GDK_GC_SUBWINDOW", "subwindow" },
-            { GDK_GC_TS_X_ORIGIN, "GDK_GC_TS_X_ORIGIN", "ts-x-origin" },
-            { GDK_GC_TS_Y_ORIGIN, "GDK_GC_TS_Y_ORIGIN", "ts-y-origin" },
-            { GDK_GC_CLIP_X_ORIGIN, "GDK_GC_CLIP_X_ORIGIN", "clip-x-origin" },
-            { GDK_GC_CLIP_Y_ORIGIN, "GDK_GC_CLIP_Y_ORIGIN", "clip-y-origin" },
-            { GDK_GC_EXPOSURES, "GDK_GC_EXPOSURES", "exposures" },
-            { GDK_GC_LINE_WIDTH, "GDK_GC_LINE_WIDTH", "line-width" },
-            { GDK_GC_LINE_STYLE, "GDK_GC_LINE_STYLE", "line-style" },
-            { GDK_GC_CAP_STYLE, "GDK_GC_CAP_STYLE", "cap-style" },
-            { GDK_GC_JOIN_STYLE, "GDK_GC_JOIN_STYLE", "join-style" },
-            { 0, NULL, NULL }
-        };
-        etype = g_flags_register_static (g_intern_static_string ("GdkGCValuesMask"), values);
-    }
-    return etype;
-}
-
-/* enumerations from "gdkimage.h" */
-GType
-gdk_image_type_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_IMAGE_NORMAL, "GDK_IMAGE_NORMAL", "normal" },
-            { GDK_IMAGE_SHARED, "GDK_IMAGE_SHARED", "shared" },
-            { GDK_IMAGE_FASTEST, "GDK_IMAGE_FASTEST", "fastest" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkImageType"), values);
-    }
-    return etype;
-}
-
 /* enumerations from "gdkproperty.h" */
 GType
 gdk_prop_mode_get_type (void)
@@ -608,23 +450,6 @@ gdk_prop_mode_get_type (void)
     return etype;
 }
 
-/* enumerations from "gdkrgb.h" */
-GType
-gdk_rgb_dither_get_type (void)
-{
-    static GType etype = 0;
-    if (G_UNLIKELY(etype == 0)) {
-        static const GEnumValue values[] = {
-            { GDK_RGB_DITHER_NONE, "GDK_RGB_DITHER_NONE", "none" },
-            { GDK_RGB_DITHER_NORMAL, "GDK_RGB_DITHER_NORMAL", "normal" },
-            { GDK_RGB_DITHER_MAX, "GDK_RGB_DITHER_MAX", "max" },
-            { 0, NULL, NULL }
-        };
-        etype = g_enum_register_static (g_intern_static_string ("GdkRgbDither"), values);
-    }
-    return etype;
-}
-
 /* enumerations from "gdktypes.h" */
 GType
 gdk_byte_order_get_type (void)
