@@ -51,6 +51,9 @@ struct _GdkWindowImplIface
   void         (* lower)                (GdkWindow       *window);
   void         (* restack_under)        (GdkWindow       *window,
 					 GList           *native_siblings);
+  void         (* restack_toplevel)     (GdkWindow       *window,
+					 GdkWindow       *sibling,
+					 gboolean        above);
 
   void         (* move_resize)          (GdkWindow       *window,
                                          gboolean         with_move,
@@ -72,10 +75,11 @@ struct _GdkWindowImplIface
                                          gint             x,
                                          gint             y);
   void         (* clear_region)         (GdkWindow       *window,
-					 GdkRegion       *region,
+					 cairo_region_t       *region,
 					 gboolean         send_expose);
-  
-  void         (* set_cursor)           (GdkWindow       *window,
+
+  void         (* set_device_cursor)    (GdkWindow       *window,
+                                         GdkDevice       *device,
                                          GdkCursor       *cursor);
 
   void         (* get_geometry)         (GdkWindow       *window,
@@ -92,17 +96,18 @@ struct _GdkWindowImplIface
   gint         (* get_deskrelative_origin) (GdkWindow       *window,
                                          gint            *x,
                                          gint            *y);
-  gboolean     (* get_pointer)          (GdkWindow       *window,
+  gboolean     (* get_device_state)     (GdkWindow       *window,
+                                         GdkDevice       *device,
                                          gint            *x,
                                          gint            *y,
-					 GdkModifierType  *mask);
+                                         GdkModifierType *mask);
 
   void         (* shape_combine_region) (GdkWindow       *window,
-                                         const GdkRegion *shape_region,
+                                         const cairo_region_t *shape_region,
                                          gint             offset_x,
                                          gint             offset_y);
   void         (* input_shape_combine_region) (GdkWindow       *window,
-					       const GdkRegion *shape_region,
+					       const cairo_region_t *shape_region,
 					       gint             offset_x,
 					       gint             offset_y);
 
@@ -116,10 +121,15 @@ struct _GdkWindowImplIface
    * for destroying the region later.
    */
   gboolean     (* queue_antiexpose)     (GdkWindow       *window,
-					 GdkRegion       *update_area);
-  void         (* queue_translation)    (GdkWindow       *window,
-					 GdkGC           *gc,
-					 GdkRegion       *area,
+					 cairo_region_t  *update_area);
+
+  /* Called to move @area inside @window by @dx x @dy pixels. @area is 
+   * guaranteed to be inside @window. If part of @area is not invisible or
+   * invalid, it is this function's job to queue expose events in those 
+   * areas.
+   */
+  void         (* translate)            (GdkWindow       *window,
+					 cairo_region_t  *area,
 					 gint            dx,
 					 gint            dy);
 
@@ -139,10 +149,7 @@ struct _GdkWindowImplIface
   void         (* destroy)              (GdkWindow       *window,
 					 gboolean         recursing,
 					 gboolean         foreign_destroy);
-
-  void         (* input_window_destroy) (GdkWindow       *window);
-  void         (* input_window_crossing)(GdkWindow       *window,
-					 gboolean         enter);
+  gboolean     supports_native_bg;
 };
 
 /* Interface Functions */
@@ -162,7 +169,7 @@ struct _GdkWindowRedirect
   gint width;
   gint height;
 
-  GdkRegion *damage;
+  cairo_region_t *damage;
   guint damage_idle;
 };
 
