@@ -93,25 +93,26 @@
 #define WM_APPCOMMAND 0x319
 #endif
 
+#ifndef CF_DIBV5
+#define CF_DIBV5 17
+#endif
+
+
 /* Define some combinations of GdkDebugFlags */
 #define GDK_DEBUG_EVENTS_OR_COLORMAP (GDK_DEBUG_EVENTS|GDK_DEBUG_COLORMAP)
 #define GDK_DEBUG_EVENTS_OR_INPUT (GDK_DEBUG_EVENTS|GDK_DEBUG_INPUT)
 #define GDK_DEBUG_PIXMAP_OR_COLORMAP (GDK_DEBUG_PIXMAP|GDK_DEBUG_COLORMAP)
 #define GDK_DEBUG_MISC_OR_COLORMAP (GDK_DEBUG_MISC|GDK_DEBUG_COLORMAP)
+#define GDK_DEBUG_MISC_OR_EVENTS (GDK_DEBUG_MISC|GDK_DEBUG_EVENTS)
 
-#define GDK_TYPE_GC_WIN32              (_gdk_gc_win32_get_type ())
-#define GDK_GC_WIN32(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GDK_TYPE_GC_WIN32, GdkGCWin32))
-#define GDK_GC_WIN32_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), GDK_TYPE_GC_WIN32, GdkGCWin32Class))
-#define GDK_IS_GC_WIN32(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), GDK_TYPE_GC_WIN32))
-#define GDK_IS_GC_WIN32_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GDK_TYPE_GC_WIN32))
-#define GDK_GC_WIN32_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), GDK_TYPE_GC_WIN32, GdkGCWin32Class))
+//#define GDK_WINDOW_SCREEN(win)         (_gdk_screen)
+GdkScreen *GDK_WINDOW_SCREEN(GObject *win);
+
+#define GDK_WINDOW_IS_WIN32(win)        (GDK_IS_WINDOW_IMPL_WIN32 (((GdkWindowObject *)win)->impl))
 
 typedef struct _GdkColormapPrivateWin32 GdkColormapPrivateWin32;
 typedef struct _GdkCursorPrivate        GdkCursorPrivate;
 typedef struct _GdkWin32SingleFont      GdkWin32SingleFont;
-typedef struct _GdkFontPrivateWin32     GdkFontPrivateWin32;
-typedef struct _GdkGCWin32		GdkGCWin32;
-typedef struct _GdkGCWin32Class		GdkGCWin32Class;
 
 struct _GdkCursorPrivate
 {
@@ -127,13 +128,6 @@ struct _GdkWin32SingleFont
   FONTSIGNATURE fs;
 };
 
-struct _GdkFontPrivateWin32
-{
-  GdkFontPrivate base;
-  GSList *fonts;		/* List of GdkWin32SingleFonts */
-  GSList *names;
-};
-
 struct _GdkVisualClass
 {
   GObjectClass parent_class;
@@ -156,49 +150,6 @@ struct _GdkColormapPrivateWin32
   GdkColorInfo *info;
 };
 
-struct _GdkGCWin32
-{
-  GdkGC parent_instance;
-
-  /* A Windows Device Context (DC) is not equivalent to an X11
-   * GC. We can use a DC only in the window for which it was
-   * allocated, or (in the case of a memory DC) with the bitmap that
-   * has been selected into it. Thus, we have to release and
-   * reallocate a DC each time the GdkGC is used to paint into a new
-   * window or pixmap. We thus keep all the necessary values in the
-   * GdkGCWin32 object.
-   */
-
-  HRGN hcliprgn;
-
-  GdkGCValuesMask values_mask;
-
-  GdkFont *font;
-  gint rop2;
-  GdkSubwindowMode subwindow_mode;
-  gint graphics_exposures;
-  gint pen_width;
-  DWORD pen_style;
-  GdkLineStyle line_style;
-  GdkCapStyle cap_style;
-  GdkJoinStyle join_style;
-  DWORD *pen_dashes;		/* use for PS_USERSTYLE or step-by-step rendering */
-  gint pen_num_dashes;
-  gint pen_dash_offset;
-  HBRUSH pen_hbrbg;
-
-  /* Following fields are valid while the GC exists as a Windows DC */
-  HDC hdc;
-  int saved_dc;
-
-  HPALETTE holdpal;
-};
-
-struct _GdkGCWin32Class
-{
-  GdkGCClass parent_class;
-};
-
 GType _gdk_gc_win32_get_type (void);
 
 gulong _gdk_win32_get_next_tick (gulong suggested_tick);
@@ -215,7 +166,7 @@ void _gdk_win32_window_scroll (GdkWindow *window,
 			       gint       dx,
 			       gint       dy);
 void _gdk_win32_window_move_region (GdkWindow       *window,
-				    const GdkRegion *region,
+				    const cairo_region_t *region,
 				    gint             dx,
 				    gint             dy);
 void _gdk_win32_windowing_window_get_offsets (GdkWindow *window,
@@ -223,9 +174,6 @@ void _gdk_win32_windowing_window_get_offsets (GdkWindow *window,
 					      gint      *y_offset);
 
 
-void _gdk_window_process_expose    (GdkWindow *window,
-                                    GdkRegion *invalidate_region);
-
 void _gdk_win32_selection_init (void);
 void _gdk_win32_dnd_exit (void);
 
@@ -233,25 +181,6 @@ void	 gdk_win32_handle_table_insert  (HANDLE   *handle,
 					 gpointer data);
 void	 gdk_win32_handle_table_remove  (HANDLE handle);
 
-GdkGC    *_gdk_win32_gc_new             (GdkDrawable        *drawable,
-					 GdkGCValues        *values,
-					 GdkGCValuesMask     values_mask);
-
-GdkImage *_gdk_win32_get_image 		(GdkDrawable *drawable,
-					 gint         x,
-					 gint         y,
-					 gint         width,
-					 gint         height);
-
-GdkImage *_gdk_win32_copy_to_image      (GdkDrawable *drawable,
-					 GdkImage    *image,
-					 gint         src_x,
-					 gint         src_y,
-					 gint         dest_x,
-					 gint         dest_y,
-					 gint         width,
-					 gint         height);
-
 void      _gdk_win32_blit               (gboolean              use_fg_bg,
 					 GdkDrawableImplWin32 *drawable,
 					 GdkGC       	       *gc,
@@ -268,11 +197,11 @@ COLORREF  _gdk_win32_colormap_color     (GdkColormap *colormap,
 
 HRGN	  _gdk_win32_bitmap_to_hrgn     (GdkPixmap   *bitmap);
 
-HRGN	  _gdk_win32_gdkregion_to_hrgn  (const GdkRegion *region,
-					 gint             x_origin,
-					 gint             y_origin);
+HRGN	  _gdk_win32_cairo_region_to_hrgn (const cairo_region_t *region,
+					   gint                  x_origin,
+					   gint                  y_origin);
 
-GdkRegion *_gdk_win32_hrgn_to_region    (HRGN hrgn);
+cairo_region_t *_gdk_win32_hrgn_to_region    (HRGN hrgn);
 
 void	_gdk_win32_adjust_client_rect   (GdkWindow *window,
 					 RECT      *RECT);
@@ -281,18 +210,9 @@ void    _gdk_selection_property_delete (GdkWindow *);
 
 void    _gdk_dropfiles_store (gchar *data);
 
-void    _gdk_wchar_text_handle    (GdkFont       *font,
-				   const wchar_t *wcstr,
-				   int            wclen,
-				   void         (*handler)(GdkWin32SingleFont *,
-							   const wchar_t *,
-							   int,
-							   void *),
-				   void          *arg);
-
 void       _gdk_push_modal_window   (GdkWindow *window);
 void       _gdk_remove_modal_window (GdkWindow *window);
-GdkWindow *_gdk_modal_current       ();
+GdkWindow *_gdk_modal_current       (void);
 
 
 #ifdef G_ENABLE_DEBUG
@@ -308,9 +228,13 @@ gchar *_gdk_win32_fill_style_to_string (GdkFill      fill);
 gchar *_gdk_win32_function_to_string   (GdkFunction  function);
 gchar *_gdk_win32_join_style_to_string (GdkJoinStyle join_style);
 gchar *_gdk_win32_line_style_to_string (GdkLineStyle line_style);
+gchar *_gdk_win32_drag_protocol_to_string (GdkDragProtocol protocol);
 gchar *_gdk_win32_gcvalues_mask_to_string (GdkGCValuesMask mask);
 gchar *_gdk_win32_window_state_to_string (GdkWindowState state);
 gchar *_gdk_win32_window_style_to_string (LONG style);
+gchar *_gdk_win32_window_exstyle_to_string (LONG style);
+gchar *_gdk_win32_window_pos_bits_to_string (UINT flags);
+gchar *_gdk_win32_drag_action_to_string (GdkDragAction actions);
 gchar *_gdk_win32_drawable_description (GdkDrawable *d);
 
 gchar *_gdk_win32_rop2_to_string       (int          rop2);
@@ -327,27 +251,21 @@ gchar *_gdk_win32_data_to_string       (const guchar*data,
 gchar *_gdk_win32_rect_to_string       (const RECT  *rect);
 
 gchar *_gdk_win32_gdkrectangle_to_string (const GdkRectangle *rect);
-gchar *_gdk_win32_gdkregion_to_string    (const GdkRegion    *box);
+gchar *_gdk_win32_cairo_region_to_string (const cairo_region_t    *box);
+
+void   _gdk_win32_print_event            (const GdkEvent     *event);
 
 #endif
 
 gchar  *_gdk_win32_last_error_string (void);
 void    _gdk_win32_api_failed        (const gchar *where,
-				     gint line,
 				     const gchar *api);
 void    _gdk_other_api_failed        (const gchar *where,
-				     gint line,
 				     const gchar *api);
 
-#if defined(__GNUC__) && (__GNUC__ < 3)
-#define WIN32_API_FAILED(api) _gdk_win32_api_failed (__FILE__ ":" __PRETTY_FUNCTION__, __LINE__, api)
+#define WIN32_API_FAILED(api) _gdk_win32_api_failed (G_STRLOC , api)
 #define WIN32_GDI_FAILED(api) WIN32_API_FAILED (api)
-#define OTHER_API_FAILED(api) _gdk_other_api_failed (__FILE__ ":" __PRETTY_FUNCTION__, __LINE__, api)
-#else
-#define WIN32_API_FAILED(api) _gdk_win32_api_failed (__FILE__, __LINE__, api)
-#define WIN32_GDI_FAILED(api) WIN32_API_FAILED (api)
-#define OTHER_API_FAILED(api) _gdk_other_api_failed (__FILE__, __LINE__, api)
-#endif
+#define OTHER_API_FAILED(api) _gdk_other_api_failed (G_STRLOC, api)
  
 /* These two macros call a GDI or other Win32 API and if the return
  * value is zero or NULL, print a warning message. The majority of GDI
@@ -397,34 +315,65 @@ extern guint		 _gdk_keymap_serial;
 extern gboolean		 _gdk_keyboard_has_altgr;
 extern guint		 _scancode_rshift;
 
-/* Registered clipboard formats */
-extern WORD		 _cf_utf8_string;
-extern WORD		 _cf_image_bmp;
-
 /* GdkAtoms: properties, targets and types */
-extern GdkAtom		 _gdk_selection_property;
+extern GdkAtom		 _gdk_selection;
 extern GdkAtom		 _wm_transient_for;
 extern GdkAtom		 _targets;
+extern GdkAtom		 _delete;
 extern GdkAtom		 _save_targets;
 extern GdkAtom           _utf8_string;
 extern GdkAtom		 _text;
 extern GdkAtom		 _compound_text;
 extern GdkAtom		 _text_uri_list;
+extern GdkAtom		 _text_html;
+extern GdkAtom		 _image_png;
+extern GdkAtom		 _image_jpeg;
 extern GdkAtom		 _image_bmp;
+extern GdkAtom		 _image_gif;
 
 /* DND selections */
 extern GdkAtom           _local_dnd;
 extern GdkAtom		 _gdk_win32_dropfiles;
 extern GdkAtom		 _gdk_ole2_dnd;
 
+/* Clipboard formats */
+extern UINT		 _cf_png;
+extern UINT		 _cf_jfif;
+extern UINT		 _cf_gif;
+extern UINT		 _cf_url;
+extern UINT		 _cf_html_format;
+extern UINT		 _cf_text_html;
+
+/* OLE-based DND state */
+typedef enum {
+  GDK_WIN32_DND_NONE,
+  GDK_WIN32_DND_PENDING,
+  GDK_WIN32_DND_DROPPED,
+  GDK_WIN32_DND_FAILED,
+  GDK_WIN32_DND_DRAGGING,
+} GdkWin32DndState;
+
+extern GdkWin32DndState  _dnd_target_state;
+extern GdkWin32DndState  _dnd_source_state;
+
+void _gdk_win32_dnd_do_dragdrop (void);
+void _gdk_win32_ole2_dnd_property_change (GdkAtom       type,
+					  gint          format,
+					  const guchar *data,
+					  gint          nelements);
+
+void  _gdk_win32_begin_modal_call (void);
+void  _gdk_win32_end_modal_call (void);
+
+
 /* Options */
 extern gboolean		 _gdk_input_ignore_wintab;
 extern gint		 _gdk_max_colors;
 
 #define GDK_WIN32_COLORMAP_DATA(cmap) ((GdkColormapPrivateWin32 *) GDK_COLORMAP (cmap)->windowing_data)
 
-/* TRUE while a user-initiated window move or resize operation is in progress */
-extern gboolean		 _sizemove_in_progress;
+/* TRUE while a modal sizing, moving, or dnd operation is in progress */
+extern gboolean		_modal_operation_in_progress;
 
 /* TRUE when we are emptying the clipboard ourselves */
 extern gboolean		_ignore_destroy_clipboard;
@@ -450,12 +399,11 @@ HICON _gdk_win32_pixbuf_to_hcursor (GdkPixbuf *pixbuf,
 gboolean _gdk_win32_pixbuf_to_hicon_supports_alpha (void);
 
 /* Initialization */
-void _gdk_windowing_window_init (void);
+void _gdk_windowing_window_init (GdkScreen *screen);
 void _gdk_root_window_size_init (void);
 void _gdk_monitor_init(void);
 void _gdk_visual_init (void);
 void _gdk_dnd_init    (void);
-void _gdk_windowing_image_init  (void);
 void _gdk_events_init (void);
 void _gdk_input_init  (GdkDisplay *display);
 
