@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 
 #define GDK_PIXBUF_ENABLE_BACKEND
 
@@ -40,14 +40,153 @@
 
 #include "gdkprivate-x11.h"
 #include "gdkcursor.h"
+#include "gdkdisplay-x11.h"
 #include "gdkpixmap-x11.h"
 #include "gdkx.h"
 #include <gdk/gdkpixmap.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include "gdkalias.h"
 
 static guint theme_serial = 0;
 
+/* cursor_cache holds a cache of non-pixmap cursors to avoid expensive 
+ * libXcursor searches, cursors are added to it but only removed when
+ * their display is closed. We make the assumption that since there are 
+ * a small number of display's and a small number of cursor's that this 
+ * list will stay small enough not to be a problem.
+ */
+static GSList* cursor_cache = NULL;
+
+struct cursor_cache_key
+{
+  GdkDisplay* display;
+  GdkCursorType type;
+  const char* name;
+};
+
+/* Caller should check if there is already a match first.
+ * Cursor MUST be either a typed cursor or a pixmap with 
+ * a non-NULL name.
+ */
+static void
+add_to_cache (GdkCursorPrivate* cursor)
+{
+  cursor_cache = g_slist_prepend (cursor_cache, cursor);
+
+  /* Take a ref so that if the caller frees it we still have it */
+  gdk_cursor_ref ((GdkCursor*) cursor);
+}
+
+/* Returns 0 on a match
+ */
+static gint
+cache_compare_func (gconstpointer listelem, 
+                    gconstpointer target)
+{
+  GdkCursorPrivate* cursor = (GdkCursorPrivate*)listelem;
+  struct cursor_cache_key* key = (struct cursor_cache_key*)target;
+
+  if ((cursor->cursor.type != key->type) ||
+      (cursor->display != key->display))
+    return 1; /* No match */
+  
+  /* Elements marked as pixmap must be named cursors 
+   * (since we don't store normal pixmap cursors 
+   */
+  if (key->type == GDK_CURSOR_IS_PIXMAP)
+    return strcmp (key->name, cursor->name);
+
+  return 0; /* Match */
+}
+
+/* Returns the cursor if there is a match, NULL if not
+ * For named cursors type shall be GDK_CURSOR_IS_PIXMAP
+ * For unnamed, typed cursors, name shall be NULL
+ */
+static GdkCursorPrivate*
+find_in_cache (GdkDisplay    *display, 
+               GdkCursorType  type,
+               const char    *name)
+{
+  GSList* res;
+  struct cursor_cache_key key;
+
+  key.display = display;
+  key.type = type;
+  key.name = name;
+
+  res = g_slist_find_custom (cursor_cache, &key, cache_compare_func);
+
+  if (res)
+    return (GdkCursorPrivate *) res->data;
+
+  return NULL;
+}
+
+/* Called by gdk_display_x11_finalize to flush any cached cursors
+ * for a dead display.
+ */
+void 
+_gdk_x11_cursor_display_finalize (GdkDisplay *display)
+{
+  GSList* item;
+  GSList** itemp; /* Pointer to the thing to fix when we delete an item */
+  item = cursor_cache;
+  itemp = &cursor_cache;
+  while (item)
+    {
+      GdkCursorPrivate* cursor = (GdkCursorPrivate*)(item->data);
+      if (cursor->display == display)
+        {
+	  GSList* olditem;
+          gdk_cursor_unref ((GdkCursor*) cursor);
+	  /* Remove this item from the list */
+	  *(itemp) = item->next;
+	  olditem = item;
+	  item = g_slist_next (item);
+	  g_slist_free_1 (olditem);
+        } 
+      else 
+        {
+	  itemp = &(item->next);
+	  item = g_slist_next (item);
+	}
+    }
+}
+
+static Cursor
+get_blank_cursor (GdkDisplay *display)
+{
+  GdkScreen *screen;
+  GdkPixmap *pixmap;
+  Pixmap source_pixmap;
+  XColor color;
+  Cursor cursor;
+  cairo_t *cr;
+
+  screen = gdk_display_get_default_screen (display);
+  pixmap = gdk_pixmap_new (gdk_screen_get_root_window (screen), 1, 1, 1);
+  /* Clear Pixmap */
+  cr = gdk_cairo_create (pixmap);
+  cairo_set_operator (cr, CAIRO_OPERATOR_CLEAR);
+  cairo_paint (cr);
+  cairo_destroy (cr);
+ 
+  source_pixmap = GDK_PIXMAP_XID (pixmap);
+
+  color.pixel = 0; 
+  color.red = color.blue = color.green = 0;
+  
+  if (display->closed)
+    cursor = None;
+  else
+    cursor = XCreatePixmapCursor (GDK_DISPLAY_XDISPLAY (display),
+                                  source_pixmap, source_pixmap,
+                                  &color, &color, 1, 1);
+  g_object_unref (pixmap);
+
+  return cursor;
+}
+
 /**
  * gdk_cursor_new_for_display:
  * @display: the #GdkDisplay for which the cursor will be created
@@ -107,11 +246,11 @@ static guint theme_serial = 0;
  * <listitem><para>
  * <inlinegraphic format="PNG" fileref="sb_v_double_arrow.png"></inlinegraphic> #GDK_SB_V_DOUBLE_ARROW (move horizontal splitter)
  * </para></listitem>
+ * <listitem><para>
+ * #GDK_BLANK_CURSOR (Blank cursor). Since 2.16
+ * </para></listitem>
  * </itemizedlist>
  *
- * To make the cursor invisible, use gdk_cursor_new_from_pixmap() to create
- * a cursor with no pixels in it.
- * 
  * Return value: a new #GdkCursor
  *
  * Since: 2.2
@@ -127,9 +266,29 @@ gdk_cursor_new_for_display (GdkDisplay    *display,
   g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
 
   if (display->closed)
-    xcursor = None;
-  else
-    xcursor = XCreateFontCursor (GDK_DISPLAY_XDISPLAY (display), cursor_type);
+    {
+      xcursor = None;
+    } 
+  else 
+    {
+      private = find_in_cache (display, cursor_type, NULL);
+
+      if (private)
+        {
+          /* Cache had it, add a ref for this user */
+          gdk_cursor_ref ((GdkCursor*) private);
+       
+          return (GdkCursor*) private;
+        } 
+      else 
+        {
+	  if (cursor_type != GDK_BLANK_CURSOR)
+            xcursor = XCreateFontCursor (GDK_DISPLAY_XDISPLAY (display),
+                                         cursor_type);
+	  else
+	    xcursor = get_blank_cursor (display);
+       }
+    }
   
   private = g_new (GdkCursorPrivate, 1);
   private->display = display;
@@ -141,6 +300,9 @@ gdk_cursor_new_for_display (GdkDisplay    *display,
   cursor->type = cursor_type;
   cursor->ref_count = 1;
   
+  if (xcursor != None)
+    add_to_cache (private);
+
   return cursor;
 }
 
@@ -158,44 +320,7 @@ gdk_cursor_new_for_display (GdkDisplay    *display,
  * 
  * Creates a new cursor from a given pixmap and mask. Both the pixmap and mask
  * must have a depth of 1 (i.e. each pixel has only 2 values - on or off).
- * The standard cursor size is 16 by 16 pixels. You can create a bitmap 
- * from inline data as in the below example.
- * 
- * <example><title>Creating a custom cursor</title>
- * <programlisting>
- * /<!-- -->* This data is in X bitmap format, and can be created with the 'bitmap'
- *    utility. *<!-- -->/
- * &num;define cursor1_width 16
- * &num;define cursor1_height 16
- * static unsigned char cursor1_bits[] = {
- *   0x80, 0x01, 0x40, 0x02, 0x20, 0x04, 0x10, 0x08, 0x08, 0x10, 0x04, 0x20,
- *   0x82, 0x41, 0x41, 0x82, 0x41, 0x82, 0x82, 0x41, 0x04, 0x20, 0x08, 0x10,
- *   0x10, 0x08, 0x20, 0x04, 0x40, 0x02, 0x80, 0x01};
- *  
- * static unsigned char cursor1mask_bits[] = {
- *   0x80, 0x01, 0xc0, 0x03, 0x60, 0x06, 0x30, 0x0c, 0x18, 0x18, 0x8c, 0x31,
- *   0xc6, 0x63, 0x63, 0xc6, 0x63, 0xc6, 0xc6, 0x63, 0x8c, 0x31, 0x18, 0x18,
- *   0x30, 0x0c, 0x60, 0x06, 0xc0, 0x03, 0x80, 0x01};
- *  
- *  
- *  GdkCursor *cursor;
- *  GdkPixmap *source, *mask;
- *  GdkColor fg = { 0, 65535, 0, 0 }; /<!-- -->* Red. *<!-- -->/
- *  GdkColor bg = { 0, 0, 0, 65535 }; /<!-- -->* Blue. *<!-- -->/
- *  
- *  
- *  source = gdk_bitmap_create_from_data (NULL, cursor1_bits,
- *                                        cursor1_width, cursor1_height);
- *  mask = gdk_bitmap_create_from_data (NULL, cursor1mask_bits,
- *                                      cursor1_width, cursor1_height);
- *  cursor = gdk_cursor_new_from_pixmap (source, mask, &amp;fg, &amp;bg, 8, 8);
- *  gdk_pixmap_unref (source);
- *  gdk_pixmap_unref (mask);
- *  
- *  
- *  gdk_window_set_cursor (widget->window, cursor);
- * </programlisting>
- * </example>
+ * The standard cursor size is 16 by 16 pixels.
  *
  * Return value: a new #GdkCursor.
  **/
@@ -401,10 +526,15 @@ _gdk_x11_cursor_update_theme (GdkCursor *cursor)
   Display *xdisplay;
   GdkCursorPrivate *private;
   Cursor new_cursor = None;
+  GdkDisplayX11 *display_x11;
 
   private = (GdkCursorPrivate *) cursor;
   xdisplay = GDK_DISPLAY_XDISPLAY (private->display);
-	  
+  display_x11 = GDK_DISPLAY_X11 (private->display);
+
+  if (!display_x11->have_xfixes)
+    return;
+
   if (private->serial == theme_serial)
     return;
 
@@ -412,6 +542,9 @@ _gdk_x11_cursor_update_theme (GdkCursor *cursor)
 
   if (private->xcursor != None)
     {
+      if (cursor->type == GDK_BLANK_CURSOR)
+        return;
+
       if (cursor->type == GDK_CURSOR_IS_PIXMAP)
 	{
 	  if (private->name)
@@ -421,25 +554,20 @@ _gdk_x11_cursor_update_theme (GdkCursor *cursor)
 	new_cursor = XcursorShapeLoadCursor (xdisplay, cursor->type);
       
       if (new_cursor != None)
-	XFixesChangeCursor (xdisplay, new_cursor, private->xcursor);
+	{
+	  XFixesChangeCursor (xdisplay, new_cursor, private->xcursor);
+ 	  private->xcursor = new_cursor;
+	}
     }
 }
 
 static void
-update_cursor (gpointer key,
-	       gpointer value,
-	       gpointer data)
+update_cursor (gpointer data,
+	       gpointer user_data)
 {
-  XID *xid = key;
   GdkCursor *cursor;
 
-  if (*xid & XID_FONT_BIT)
-    return;
-
-  if (!GDK_IS_WINDOW (value))
-    return;
-
-  cursor = _gdk_x11_window_get_cursor (GDK_WINDOW (value));
+  cursor = (GdkCursor*)(data);
 
   if (!cursor)
     return;
@@ -497,7 +625,7 @@ gdk_x11_display_set_cursor_theme (GdkDisplay  *display,
   if (size > 0)
     XcursorSetDefaultSize (xdisplay, size);
     
-  g_hash_table_foreach (display_x11->xid_ht, update_cursor, NULL);
+  g_slist_foreach (cursor_cache, update_cursor, NULL);
 }
 
 #else
@@ -673,6 +801,16 @@ gdk_cursor_new_from_name (GdkDisplay  *display,
     xcursor = None;
   else 
     {
+      private = find_in_cache (display, GDK_CURSOR_IS_PIXMAP, name);
+
+      if (private)
+        {
+          /* Cache had it, add a ref for this user */
+          gdk_cursor_ref ((GdkCursor*) private);
+
+          return (GdkCursor*) private;
+        }
+
       xdisplay = GDK_DISPLAY_XDISPLAY (display);
       xcursor = XcursorLibraryLoadCursor (xdisplay, name);
       if (xcursor == None)
@@ -688,7 +826,8 @@ gdk_cursor_new_from_name (GdkDisplay  *display,
   cursor = (GdkCursor *) private;
   cursor->type = GDK_CURSOR_IS_PIXMAP;
   cursor->ref_count = 1;
-  
+  add_to_cache (private);
+
   return cursor;
 }
 
@@ -760,11 +899,13 @@ gdk_cursor_new_from_pixbuf (GdkDisplay *display,
 {
   GdkCursor *cursor;
   GdkPixmap *pixmap, *mask;
-  guint width, height, n_channels, rowstride, i, j;
+  guint width, height, n_channels, rowstride, data_stride, i, j;
   guint8 *data, *mask_data, *pixels;
   GdkColor fg = { 0, 0, 0, 0 };
   GdkColor bg = { 0, 0xffff, 0xffff, 0xffff };
   GdkScreen *screen;
+  cairo_surface_t *image;
+  cairo_t *cr;
 
   g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
   g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
@@ -779,14 +920,15 @@ gdk_cursor_new_from_pixbuf (GdkDisplay *display,
   rowstride = gdk_pixbuf_get_rowstride (pixbuf);
   pixels = gdk_pixbuf_get_pixels (pixbuf);
 
-  data = g_new0 (guint8, (width + 7) / 8 * height);
-  mask_data = g_new0 (guint8, (width + 7) / 8 * height);
+  data_stride = 4 * ((width + 31) / 32);
+  data = g_new0 (guint8, data_stride * height);
+  mask_data = g_new0 (guint8, data_stride * height);
 
   for (j = 0; j < height; j++)
     {
       guint8 *src = pixels + j * rowstride;
-      guint8 *d = data + (width + 7) / 8 * j;
-      guint8 *md = mask_data + (width + 7) / 8 * j;
+      guint8 *d = data + data_stride * j;
+      guint8 *md = mask_data + data_stride * j;
 	
       for (i = 0; i < width; i++)
 	{
@@ -806,12 +948,29 @@ gdk_cursor_new_from_pixbuf (GdkDisplay *display,
     }
       
   screen = gdk_display_get_default_screen (display);
-  pixmap = gdk_bitmap_create_from_data (gdk_screen_get_root_window (screen), 
-					data, width, height);
+
+  pixmap = gdk_pixmap_new (gdk_screen_get_root_window (screen), 
+			   width, height, 1);
+  cr = gdk_cairo_create (pixmap);
+  image = cairo_image_surface_create_for_data (data, CAIRO_FORMAT_A1,
+                                               width, height, data_stride);
+  cairo_set_source_surface (cr, image, 0, 0);
+  cairo_surface_destroy (image);
+  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+  cairo_paint (cr);
+  cairo_destroy (cr);
+ 
+  mask = gdk_pixmap_new (gdk_screen_get_root_window (screen), 
+			 width, height, 1);
+  cr = gdk_cairo_create (mask);
+  image = cairo_image_surface_create_for_data (mask_data, CAIRO_FORMAT_A1,
+                                               width, height, data_stride);
+  cairo_set_source_surface (cr, image, 0, 0);
+  cairo_surface_destroy (image);
+  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+  cairo_paint (cr);
+  cairo_destroy (cr);
  
-  mask = gdk_bitmap_create_from_data (gdk_screen_get_root_window (screen),
-				      mask_data, width, height);
-   
   cursor = gdk_cursor_new_from_pixmap (pixmap, mask, &fg, &bg, x, y);
    
   g_object_unref (pixmap);
@@ -863,8 +1022,8 @@ gdk_display_get_default_cursor_size (GdkDisplay    *display)
 /**
  * gdk_display_get_maximal_cursor_size:
  * @display: a #GdkDisplay
- * @width: the return location for the maximal cursor width
- * @height: the return location for the maximal cursor height
+ * @width: (out): the return location for the maximal cursor width
+ * @height: (out): the return location for the maximal cursor height
  *
  * Gets the maximal size to use for cursors on @display.
  *
@@ -886,6 +1045,3 @@ gdk_display_get_maximal_cursor_size (GdkDisplay *display,
 		    GDK_WINDOW_XWINDOW (window), 
 		    128, 128, width, height);
 }
-
-#define __GDK_CURSOR_X11_C__
-#include "gdkaliasdef.c"
