@@ -93,9 +93,10 @@ struct _GdkScreenX11
   /* Xinerama/RandR 1.2 */
   gint		 n_monitors;
   GdkX11Monitor	*monitors;
+  gint           primary_monitor;
 
-  /* Pango renderer object singleton */
-  PangoRenderer *renderer;
+  /* cache for window->translate vfunc */
+  GC subwindow_gcs[32];
 
   /* Xft resources for the display, used for default values for
    * the Xft/ XSETTINGS
@@ -122,12 +123,12 @@ GType       _gdk_screen_x11_get_type (void);
 GdkScreen * _gdk_x11_screen_new      (GdkDisplay *display,
 				      gint	  screen_number);
 
+void _gdk_x11_screen_setup                  (GdkScreen *screen);
 void _gdk_x11_screen_window_manager_changed (GdkScreen *screen);
 void _gdk_x11_screen_size_changed           (GdkScreen *screen,
 					     XEvent    *event);
-void _gdk_x11_screen_process_owner_change (GdkScreen *screen,
-					   XEvent    *event);
-void _gdk_x11_screen_process_monitors_change (GdkScreen *screen);
+void _gdk_x11_screen_process_owner_change   (GdkScreen *screen,
+					     XEvent    *event);
 
 G_END_DECLS
 
