@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -37,6 +37,7 @@ G_BEGIN_DECLS
 #define GTK_ACCESSIBLE_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_ACCESSIBLE, GtkAccessibleClass))
 
 typedef struct _GtkAccessible                GtkAccessible;
+typedef struct _GtkAccessiblePriv            GtkAccessiblePriv;
 typedef struct _GtkAccessibleClass           GtkAccessibleClass;
 
   /*
@@ -46,11 +47,8 @@ struct _GtkAccessible
 {
   AtkObject parent;
 
-  /*
-   * The GtkWidget whose properties and features are exported via this 
-   * accessible instance.
-   */
-  GtkWidget *GSEAL (widget);
+  /*< private >*/
+  GtkAccessiblePriv *priv;
 };
 
 struct _GtkAccessibleClass
@@ -68,7 +66,10 @@ struct _GtkAccessibleClass
 
 GType gtk_accessible_get_type (void) G_GNUC_CONST;
 
-void gtk_accessible_connect_widget_destroyed    (GtkAccessible     *accessible);
+void        gtk_accessible_set_widget                  (GtkAccessible     *accessible,
+                                                        GtkWidget         *widget);
+GtkWidget*  gtk_accessible_get_widget                  (GtkAccessible     *accessible);
+void        gtk_accessible_connect_widget_destroyed    (GtkAccessible     *accessible);
 
 G_END_DECLS
 
