@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -32,9 +32,9 @@
 #define __GTK_ASPECT_FRAME_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkframe.h>
 
+
 G_BEGIN_DECLS
 
 #define GTK_TYPE_ASPECT_FRAME            (gtk_aspect_frame_get_type ())
@@ -44,20 +44,16 @@ G_BEGIN_DECLS
 #define GTK_IS_ASPECT_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_ASPECT_FRAME))
 #define GTK_ASPECT_FRAME_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_ASPECT_FRAME, GtkAspectFrameClass))
 
-
 typedef struct _GtkAspectFrame       GtkAspectFrame;
+typedef struct _GtkAspectFramePriv   GtkAspectFramePriv;
 typedef struct _GtkAspectFrameClass  GtkAspectFrameClass;
 
 struct _GtkAspectFrame
 {
   GtkFrame frame;
 
-  gfloat xalign;
-  gfloat yalign;
-  gfloat ratio;
-  gboolean obey_child;
-
-  GtkAllocation center_allocation;
+  /*< private >*/
+  GtkAspectFramePriv *priv;
 };
 
 struct _GtkAspectFrameClass
