@@ -42,21 +42,18 @@ G_BEGIN_DECLS
 #define GTK_IS_BUTTON_BOX(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_BUTTON_BOX))
 #define GTK_IS_BUTTON_BOX_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_BUTTON_BOX))
 #define GTK_BUTTON_BOX_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_BUTTON_BOX, GtkButtonBoxClass))
-  
 
-#define GTK_BUTTONBOX_DEFAULT -1
- 
+
 typedef struct _GtkButtonBox       GtkButtonBox;
+typedef struct _GtkButtonBoxPriv   GtkButtonBoxPriv;
 typedef struct _GtkButtonBoxClass  GtkButtonBoxClass;
 
 struct _GtkButtonBox
 {
   GtkBox box;
-  gint GSEAL (child_min_width);
-  gint GSEAL (child_min_height);
-  gint GSEAL (child_ipad_x);
-  gint GSEAL (child_ipad_y);
-  GtkButtonBoxStyle GSEAL (layout_style);
+
+  /*< private >*/
+  GtkButtonBoxPriv *priv;
 };
 
 struct _GtkButtonBoxClass
@@ -76,12 +73,6 @@ void              gtk_button_box_set_child_secondary (GtkButtonBox      *widget,
 						      GtkWidget         *child,
 						      gboolean           is_secondary);
 
-/* Internal method - do not use. */
-void _gtk_button_box_child_requisition (GtkWidget *widget,
-					int       *nvis_children,
-					int       *nvis_secondaries,
-					int       *width,
-					int       *height);
 G_END_DECLS
 
 #endif /* __GTK_BUTTON_BOX_H__ */
