@@ -253,7 +253,7 @@
 #include "gtkwindow.h"
 #include "gtkicontheme.h"
 #include "gtkstock.h"
-#include "gtkalias.h"
+
 
 static void gtk_builder_class_init     (GtkBuilderClass *klass);
 static void gtk_builder_init           (GtkBuilder      *builder);
@@ -1545,12 +1545,10 @@ gtk_builder_value_from_string_type (GtkBuilder   *builder,
     case G_TYPE_BOXED:
       if (G_VALUE_HOLDS (value, GDK_TYPE_COLOR))
         {
-          GdkColor colour = { 0, };
+          GdkColor color = { 0, };
 
-          if (gdk_color_parse (string, &colour) &&
-              gdk_colormap_alloc_color (gtk_widget_get_default_colormap (),
-                                        &colour, FALSE, TRUE))
-            g_value_set_boxed (value, &colour);
+          if (gdk_color_parse (string, &color))
+            g_value_set_boxed (value, &color);
           else
             {
 	      g_set_error (error,
@@ -1848,6 +1846,3 @@ _gtk_builder_get_absolute_filename (GtkBuilder *builder, const gchar *string)
   
   return filename;
 }
-
-#define __GTK_BUILDER_C__
-#include "gtkaliasdef.c"
