@@ -52,29 +52,16 @@ typedef enum
 #define GTK_IS_CELL_RENDERER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_CELL_RENDERER))
 #define GTK_CELL_RENDERER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_CELL_RENDERER, GtkCellRendererClass))
 
-typedef struct _GtkCellRenderer GtkCellRenderer;
+typedef struct _GtkCellRenderer      GtkCellRenderer;
+typedef struct _GtkCellRendererPriv  GtkCellRendererPriv;
 typedef struct _GtkCellRendererClass GtkCellRendererClass;
 
 struct _GtkCellRenderer
 {
   GtkObject parent;
 
-  gfloat GSEAL (xalign);
-  gfloat GSEAL (yalign);
-
-  gint GSEAL (width);
-  gint GSEAL (height);
-
-  guint16 GSEAL (xpad);
-  guint16 GSEAL (ypad);
-
-  guint GSEAL (mode) : 2;
-  guint GSEAL (visible) : 1;
-  guint GSEAL (is_expander) : 1;
-  guint GSEAL (is_expanded) : 1;
-  guint GSEAL (cell_background_set) : 1;
-  guint GSEAL (sensitive) : 1;
-  guint GSEAL (editing) : 1;
+  /* <private> */
+  GtkCellRendererPriv *priv;
 };
 
 struct _GtkCellRendererClass
