@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -28,14 +28,15 @@
 
 G_BEGIN_DECLS
 
-#define GTK_TYPE_CELL_RENDERER_ACCEL		(gtk_cell_renderer_accel_get_type ())
-#define GTK_CELL_RENDERER_ACCEL(obj)		(GTK_CHECK_CAST ((obj), GTK_TYPE_CELL_RENDERER_ACCEL, GtkCellRendererAccel))
-#define GTK_CELL_RENDERER_ACCEL_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_CELL_RENDERER_ACCEL, GtkCellRendererAccelClass))
-#define GTK_IS_CELL_RENDERER_ACCEL(obj)		(GTK_CHECK_TYPE ((obj), GTK_TYPE_CELL_RENDERER_ACCEL))
-#define GTK_IS_CELL_RENDERER_ACCEL_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_CELL_RENDERER_ACCEL))
-#define GTK_CELL_RENDERER_ACCEL_GET_CLASS(obj)   (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_CELL_RENDERER_ACCEL, GtkCellRendererAccelClass))
+#define GTK_TYPE_CELL_RENDERER_ACCEL            (gtk_cell_renderer_accel_get_type ())
+#define GTK_CELL_RENDERER_ACCEL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_CELL_RENDERER_ACCEL, GtkCellRendererAccel))
+#define GTK_CELL_RENDERER_ACCEL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_CELL_RENDERER_ACCEL, GtkCellRendererAccelClass))
+#define GTK_IS_CELL_RENDERER_ACCEL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_CELL_RENDERER_ACCEL))
+#define GTK_IS_CELL_RENDERER_ACCEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_CELL_RENDERER_ACCEL))
+#define GTK_CELL_RENDERER_ACCEL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_CELL_RENDERER_ACCEL, GtkCellRendererAccelClass))
 
 typedef struct _GtkCellRendererAccel      GtkCellRendererAccel;
+typedef struct _GtkCellRendererAccelPriv  GtkCellRendererAccelPriv;
 typedef struct _GtkCellRendererAccelClass GtkCellRendererAccelClass;
 
 
@@ -51,14 +52,7 @@ struct _GtkCellRendererAccel
   GtkCellRendererText parent;
 
   /*< private >*/
-  guint accel_key;
-  GdkModifierType accel_mods;
-  guint keycode;
-  GtkCellRendererAccelMode accel_mode;
-
-  GtkWidget *edit_widget;
-  GtkWidget *grab_widget;
-  GtkWidget *sizing_label;
+  GtkCellRendererAccelPriv *priv;
 };
 
 struct _GtkCellRendererAccelClass
