@@ -27,7 +27,7 @@
 #include "gtkprivate.h"
 #include <gobject/gmarshal.h>
 #include "gtkbuildable.h"
-#include "gtkalias.h"
+
 
 typedef struct _GtkCellViewCellInfo GtkCellViewCellInfo;
 struct _GtkCellViewCellInfo
@@ -122,7 +122,6 @@ static void       gtk_cell_view_buildable_custom_tag_end       (GtkBuildable
 
 static GtkBuildableIface *parent_buildable_iface;
 
-#define GTK_CELL_VIEW_GET_PRIVATE(obj)    (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_CELL_VIEW, GtkCellViewPrivate))
 
 enum
 {
@@ -288,9 +287,14 @@ gtk_cell_view_set_property (GObject      *object,
 static void
 gtk_cell_view_init (GtkCellView *cellview)
 {
-  gtk_widget_set_has_window (GTK_WIDGET (cellview), FALSE);
+  GtkCellViewPrivate *priv;
 
-  cellview->priv = GTK_CELL_VIEW_GET_PRIVATE (cellview);
+  cellview->priv = G_TYPE_INSTANCE_GET_PRIVATE (cellview,
+                                                GTK_TYPE_CELL_VIEW,
+                                                GtkCellViewPrivate);
+  priv = cellview->priv;
+
+  gtk_widget_set_has_window (GTK_WIDGET (cellview), FALSE);
 }
 
 static void
@@ -330,7 +334,7 @@ gtk_cell_view_size_request (GtkWidget      *widget,
       gint width, height;
       GtkCellViewCellInfo *info = (GtkCellViewCellInfo *)i->data;
 
-      if (!info->cell->visible)
+      if (!gtk_cell_renderer_get_visible (info->cell))
         continue;
 
       if (!first_cell)
@@ -366,7 +370,7 @@ gtk_cell_view_size_allocate (GtkWidget     *widget,
     {
       GtkCellViewCellInfo *info = (GtkCellViewCellInfo *)i->data;
 
-      if (!info->cell->visible)
+      if (!gtk_cell_renderer_get_visible (info->cell))
         continue;
 
       if (info->expand)
@@ -385,7 +389,7 @@ gtk_cell_view_size_allocate (GtkWidget     *widget,
     {
       GtkCellViewCellInfo *info = (GtkCellViewCellInfo *)i->data;
 
-      if (!info->cell->visible)
+      if (!gtk_cell_renderer_get_visible (info->cell))
         continue;
 
       info->real_width = info->requested_width +
@@ -451,7 +455,7 @@ gtk_cell_view_expose (GtkWidget      *widget,
       if (info->pack == GTK_PACK_END)
         continue;
 
-      if (!info->cell->visible)
+      if (!gtk_cell_renderer_get_visible (info->cell))
         continue;
 
       area.width = info->real_width;
@@ -478,7 +482,7 @@ gtk_cell_view_expose (GtkWidget      *widget,
       if (info->pack == GTK_PACK_START)
         continue;
 
-      if (!info->cell->visible)
+      if (!gtk_cell_renderer_get_visible (info->cell))
         continue;
 
       area.width = info->real_width;
@@ -1064,26 +1068,6 @@ gtk_cell_view_cell_layout_get_cells (GtkCellLayout *layout)
   return g_list_reverse (retval);
 }
 
-/**
- * gtk_cell_view_get_cell_renderers:
- * @cell_view: a #GtkCellView
- *
- * Returns the cell renderers which have been added to @cell_view.
- *
- * Return value: a list of cell renderers. The list, but not the
- *   renderers has been newly allocated and should be freed with
- *   g_list_free() when no longer needed.
- *
- * Since: 2.6
- *
- * Deprecated: 2.18: use gtk_cell_layout_get_cells() instead.
- **/
-GList *
-gtk_cell_view_get_cell_renderers (GtkCellView *cell_view)
-{
-  return gtk_cell_view_cell_layout_get_cells (GTK_CELL_LAYOUT (cell_view));
-}
-
 static gboolean
 gtk_cell_view_buildable_custom_tag_start (GtkBuildable  *buildable,
 					  GtkBuilder    *builder,
@@ -1115,7 +1099,3 @@ gtk_cell_view_buildable_custom_tag_end (GtkBuildable *buildable,
     parent_buildable_iface->custom_tag_end (buildable, builder, child, tagname,
 					    data);
 }
-
-
-#define __GTK_CELL_VIEW_C__
-#include "gtkaliasdef.c"
