@@ -25,7 +25,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -46,9 +46,9 @@ G_BEGIN_DECLS
 
 
 typedef struct _GtkColorSelection       GtkColorSelection;
+typedef struct _ColorSelectionPrivate   ColorSelectionPrivate;
 typedef struct _GtkColorSelectionClass  GtkColorSelectionClass;
 
-
 typedef void (* GtkColorSelectionChangePaletteFunc) (const GdkColor    *colors,
                                                      gint               n_colors);
 typedef void (* GtkColorSelectionChangePaletteWithScreenFunc) (GdkScreen         *screen,
@@ -60,7 +60,7 @@ struct _GtkColorSelection
   GtkVBox parent_instance;
 
   /* < private_data > */
-  gpointer GSEAL (private_data);
+  ColorSelectionPrivate *private_data;
 };
 
 struct _GtkColorSelectionClass
@@ -112,24 +112,8 @@ gboolean gtk_color_selection_palette_from_string (const gchar       *str,
 gchar*   gtk_color_selection_palette_to_string   (const GdkColor    *colors,
                                                   gint               n_colors);
 
-#ifndef GTK_DISABLE_DEPRECATED
-#ifndef GDK_MULTIHEAD_SAFE
-GtkColorSelectionChangePaletteFunc           gtk_color_selection_set_change_palette_hook             (GtkColorSelectionChangePaletteFunc           func);
-#endif
-#endif
-
 GtkColorSelectionChangePaletteWithScreenFunc gtk_color_selection_set_change_palette_with_screen_hook (GtkColorSelectionChangePaletteWithScreenFunc func);
 
-#ifndef GTK_DISABLE_DEPRECATED
-/* Deprecated calls: */
-void gtk_color_selection_set_color         (GtkColorSelection *colorsel,
-					    gdouble           *color);
-void gtk_color_selection_get_color         (GtkColorSelection *colorsel,
-					    gdouble           *color);
-void gtk_color_selection_set_update_policy (GtkColorSelection *colorsel,
-					    GtkUpdateType      policy);
-#endif /* GTK_DISABLE_DEPRECATED */
-
 G_END_DECLS
 
 #endif /* __GTK_COLOR_SELECTION_H__ */
