@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -45,7 +45,7 @@ struct _GtkComboBoxEntry
   GtkComboBox parent_instance;
 
   /*< private >*/
-  GtkComboBoxEntryPrivate *GSEAL (priv);
+  GtkComboBoxEntryPrivate *priv;
 };
 
 struct _GtkComboBoxEntryClass
