@@ -30,7 +30,6 @@
 #include "gtkeditable.h"
 #include "gtkmarshalers.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
 
 
 static void gtk_editable_base_init (gpointer g_class);
@@ -149,7 +148,7 @@ gtk_editable_base_init (gpointer g_class)
  * @editable: a #GtkEditable
  * @new_text: the text to append
  * @new_text_length: the length of the text in bytes, or -1
- * @position: (in-out): location of the position text will be inserted at
+ * @position: (inout): location of the position text will be inserted at
  *
  * Inserts @new_text_length bytes of @new_text into the contents of the
  * widget, at position @position.
@@ -424,6 +423,3 @@ gtk_editable_get_editable (GtkEditable *editable)
 
   return value;
 }
-
-#define __GTK_EDITABLE_C__
-#include "gtkaliasdef.c"
