@@ -35,7 +35,6 @@
 #include "gtkmarshalers.h"
 
 #include "gtkprivate.h"
-#include "gtkalias.h"
 
 #include <string.h>
 
@@ -64,7 +63,6 @@ enum
   PROP_INLINE_SELECTION
 };
 
-#define GTK_ENTRY_COMPLETION_GET_PRIVATE(obj)(G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_ENTRY_COMPLETION, GtkEntryCompletionPrivate))
 
 static void                                                             gtk_entry_completion_cell_layout_init    (GtkCellLayoutIface      *iface);
 static void     gtk_entry_completion_set_property        (GObject      *object,
@@ -178,20 +176,20 @@ gtk_entry_completion_class_init (GtkEntryCompletionClass *klass)
    * GtkEntryCompletion::insert-prefix:
    * @widget: the object which received the signal
    * @prefix: the common prefix of all possible completions
-   * 
-   * Gets emitted when the inline autocompletion is triggered. 
-   * The default behaviour is to make the entry display the 
+   *
+   * Gets emitted when the inline autocompletion is triggered.
+   * The default behaviour is to make the entry display the
    * whole prefix and select the newly inserted part.
    *
    * Applications may connect to this signal in order to insert only a
    * smaller part of the @prefix into the entry - e.g. the entry used in
-   * the #GtkFileChooser inserts only the part of the prefix up to the 
+   * the #GtkFileChooser inserts only the part of the prefix up to the
    * next '/'.
    *
    * Return value: %TRUE if the signal has been handled
-   * 
+   *
    * Since: 2.6
-   */ 
+   */
   entry_completion_signals[INSERT_PREFIX] =
     g_signal_new (I_("insert-prefix"),
                   G_TYPE_FROM_CLASS (klass),
@@ -207,16 +205,16 @@ gtk_entry_completion_class_init (GtkEntryCompletionClass *klass)
    * @widget: the object which received the signal
    * @model: the #GtkTreeModel containing the matches
    * @iter: a #GtkTreeIter positioned at the selected match
-   * 
-   * Gets emitted when a match from the list is selected. 
-   * The default behaviour is to replace the contents of the 
-   * entry with the contents of the text column in the row 
+   *
+   * Gets emitted when a match from the list is selected.
+   * The default behaviour is to replace the contents of the
+   * entry with the contents of the text column in the row
    * pointed to by @iter.
    *
    * Return value: %TRUE if the signal has been handled
-   * 
+   *
    * Since: 2.4
-   */ 
+   */
   entry_completion_signals[MATCH_SELECTED] =
     g_signal_new (I_("match-selected"),
                   G_TYPE_FROM_CLASS (klass),
@@ -227,22 +225,22 @@ gtk_entry_completion_class_init (GtkEntryCompletionClass *klass)
                   G_TYPE_BOOLEAN, 2,
                   GTK_TYPE_TREE_MODEL,
                   GTK_TYPE_TREE_ITER);
+
   /**
    * GtkEntryCompletion::cursor-on-match:
    * @widget: the object which received the signal
    * @model: the #GtkTreeModel containing the matches
    * @iter: a #GtkTreeIter positioned at the selected match
-   * 
+   *
    * Gets emitted when a match from the cursor is on a match
-   * of the list.The default behaviour is to replace the contents
-   * of the entry with the contents of the text column in the row 
+   * of the list. The default behaviour is to replace the contents
+   * of the entry with the contents of the text column in the row
    * pointed to by @iter.
    *
    * Return value: %TRUE if the signal has been handled
-   * 
+   *
    * Since: 2.12
-   */ 
-
+   */
   entry_completion_signals[CURSOR_ON_MATCH] =
     g_signal_new (I_("cursor-on-match"),
 		  G_TYPE_FROM_CLASS (klass),
@@ -253,7 +251,7 @@ gtk_entry_completion_class_init (GtkEntryCompletionClass *klass)
 		  G_TYPE_BOOLEAN, 2,
 		  GTK_TYPE_TREE_MODEL,
 		  GTK_TYPE_TREE_ITER);
-		  
+
   /**
    * GtkEntryCompletion::action-activated:
    * @widget: the object which received the signal
@@ -423,7 +421,10 @@ gtk_entry_completion_init (GtkEntryCompletion *completion)
   GtkWidget *popup_frame;
 
   /* yes, also priv, need to keep the code readable */
-  priv = completion->priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (completion);
+  completion->priv = G_TYPE_INSTANCE_GET_PRIVATE (completion,
+                                                  GTK_TYPE_ENTRY_COMPLETION,
+                                                  GtkEntryCompletionPrivate);
+  priv = completion->priv;
 
   priv->minimum_key_length = 1;
   priv->text_column = -1;
@@ -470,7 +471,8 @@ gtk_entry_completion_init (GtkEntryCompletion *completion)
                                        GTK_SHADOW_NONE);
 
   /* a nasty hack to get the completions treeview to size nicely */
-  gtk_widget_set_size_request (GTK_SCROLLED_WINDOW (priv->scrolled_window)->vscrollbar, -1, 0);
+  gtk_widget_set_size_request (gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (priv->scrolled_window)),
+                               -1, 0);
 
   /* actions */
   priv->actions = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_BOOLEAN);
@@ -673,7 +675,7 @@ gtk_entry_completion_pack_start (GtkCellLayout   *cell_layout,
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION (cell_layout)->priv;
 
   gtk_tree_view_column_pack_start (priv->column, cell, expand);
 }
@@ -685,7 +687,7 @@ gtk_entry_completion_pack_end (GtkCellLayout   *cell_layout,
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION (cell_layout)->priv;
 
   gtk_tree_view_column_pack_end (priv->column, cell, expand);
 }
@@ -695,7 +697,7 @@ gtk_entry_completion_clear (GtkCellLayout *cell_layout)
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION (cell_layout)->priv;
 
   gtk_tree_view_column_clear (priv->column);
 }
@@ -708,7 +710,7 @@ gtk_entry_completion_add_attribute (GtkCellLayout   *cell_layout,
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION  (cell_layout)->priv;
 
   gtk_tree_view_column_add_attribute (priv->column, cell, attribute, column);
 }
@@ -722,7 +724,7 @@ gtk_entry_completion_set_cell_data_func (GtkCellLayout          *cell_layout,
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION (cell_layout)->priv;
 
   gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (priv->column),
                                       cell, func, func_data, destroy);
@@ -734,7 +736,7 @@ gtk_entry_completion_clear_attributes (GtkCellLayout   *cell_layout,
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION (cell_layout)->priv;
 
   gtk_tree_view_column_clear_attributes (priv->column, cell);
 }
@@ -746,7 +748,7 @@ gtk_entry_completion_reorder (GtkCellLayout   *cell_layout,
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION (cell_layout)->priv;
 
   gtk_cell_layout_reorder (GTK_CELL_LAYOUT (priv->column), cell, position);
 }
@@ -756,7 +758,7 @@ gtk_entry_completion_get_cells (GtkCellLayout *cell_layout)
 {
   GtkEntryCompletionPrivate *priv;
 
-  priv = GTK_ENTRY_COMPLETION_GET_PRIVATE (cell_layout);
+  priv = GTK_ENTRY_COMPLETION (cell_layout)->priv;
 
   return gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (priv->column));
 }
@@ -788,15 +790,19 @@ gtk_entry_completion_default_completion_func (GtkEntryCompletion *completion,
   if (item != NULL)
     {
       normalized_string = g_utf8_normalize (item, -1, G_NORMALIZE_ALL);
-      case_normalized_string = g_utf8_casefold (normalized_string, -1);
-      
-      if (!strncmp (key, case_normalized_string, strlen (key)))
-	ret = TRUE;
-      
-      g_free (item);
+
+      if (normalized_string != NULL)
+        {
+          case_normalized_string = g_utf8_casefold (normalized_string, -1);
+
+          if (!strncmp (key, case_normalized_string, strlen (key)))
+	    ret = TRUE;
+
+          g_free (case_normalized_string);
+        }
       g_free (normalized_string);
-      g_free (case_normalized_string);
     }
+  g_free (item);
 
   return ret;
 }
@@ -834,7 +840,7 @@ gtk_entry_completion_popup_key_event (GtkWidget   *widget,
 {
   GtkEntryCompletion *completion = GTK_ENTRY_COMPLETION (user_data);
 
-  if (!GTK_WIDGET_MAPPED (completion->priv->popup_window))
+  if (!gtk_widget_get_mapped (completion->priv->popup_window))
     return FALSE;
 
   /* propagate event to the entry */
@@ -850,7 +856,7 @@ gtk_entry_completion_popup_button_press (GtkWidget      *widget,
 {
   GtkEntryCompletion *completion = GTK_ENTRY_COMPLETION (user_data);
 
-  if (!GTK_WIDGET_MAPPED (completion->priv->popup_window))
+  if (!gtk_widget_get_mapped (completion->priv->popup_window))
     return FALSE;
 
   /* if we come here, it's usually time to popdown */
@@ -867,7 +873,7 @@ gtk_entry_completion_list_button_press (GtkWidget      *widget,
   GtkEntryCompletion *completion = GTK_ENTRY_COMPLETION (user_data);
   GtkTreePath *path = NULL;
 
-  if (!GTK_WIDGET_MAPPED (completion->priv->popup_window))
+  if (!gtk_widget_get_mapped (completion->priv->popup_window))
     return FALSE;
 
   if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
@@ -876,18 +882,23 @@ gtk_entry_completion_list_button_press (GtkWidget      *widget,
     {
       GtkTreeIter iter;
       gboolean entry_set;
+      GtkTreeModel *model;
+      GtkTreeIter child_iter;
 
       gtk_tree_model_get_iter (GTK_TREE_MODEL (completion->priv->filter_model),
                                &iter, path);
       gtk_tree_path_free (path);
+      gtk_tree_model_filter_convert_iter_to_child_iter (completion->priv->filter_model,
+                                                        &child_iter,
+                                                        &iter);
+      model = gtk_tree_model_filter_get_model (completion->priv->filter_model);
 
       g_signal_handler_block (completion->priv->entry,
-			      completion->priv->changed_id);
+                              completion->priv->changed_id);
       g_signal_emit (completion, entry_completion_signals[MATCH_SELECTED],
-                     0, GTK_TREE_MODEL (completion->priv->filter_model),
-                     &iter, &entry_set);
+                     0, model, &child_iter, &entry_set);
       g_signal_handler_unblock (completion->priv->entry,
-				completion->priv->changed_id);
+                                completion->priv->changed_id);
 
       _gtk_entry_completion_popdown (completion);
 
@@ -905,7 +916,7 @@ gtk_entry_completion_action_button_press (GtkWidget      *widget,
   GtkEntryCompletion *completion = GTK_ENTRY_COMPLETION (user_data);
   GtkTreePath *path = NULL;
 
-  if (!GTK_WIDGET_MAPPED (completion->priv->popup_window))
+  if (!gtk_widget_get_mapped (completion->priv->popup_window))
     return FALSE;
 
   _gtk_entry_reset_im_context (GTK_ENTRY (completion->priv->entry));
@@ -1013,7 +1024,7 @@ gtk_entry_completion_get_entry (GtkEntryCompletion *completion)
 /**
  * gtk_entry_completion_set_model:
  * @completion: A #GtkEntryCompletion.
- * @model: The #GtkTreeModel.
+ * @model: (allow-none): The #GtkTreeModel.
  *
  * Sets the model for a #GtkEntryCompletion. If @completion already has
  * a model set, it will remove it before setting the new model.
@@ -1051,7 +1062,7 @@ gtk_entry_completion_set_model (GtkEntryCompletion *completion,
 
   g_object_notify (G_OBJECT (completion), "model");
 
-  if (GTK_WIDGET_VISIBLE (completion->priv->popup_window))
+  if (gtk_widget_get_visible (completion->priv->popup_window))
     _gtk_entry_completion_resize_popup (completion);
 }
 
@@ -1180,7 +1191,7 @@ gtk_entry_completion_complete (GtkEntryCompletion *completion)
 
   gtk_tree_model_filter_refilter (completion->priv->filter_model);
 
-  if (GTK_WIDGET_VISIBLE (completion->priv->popup_window))
+  if (gtk_widget_get_visible (completion->priv->popup_window))
     _gtk_entry_completion_resize_popup (completion);
 }
 
@@ -1468,19 +1479,23 @@ _gtk_entry_completion_resize_popup (GtkEntryCompletion *completion)
 }
 
 void
-_gtk_entry_completion_popup (GtkEntryCompletion *completion)
+_gtk_entry_completion_popup (GtkEntryCompletion *completion,
+                             GdkDevice          *device)
 {
   GtkTreeViewColumn *column;
   GList *renderers;
   GtkWidget *toplevel;
 
-  if (GTK_WIDGET_MAPPED (completion->priv->popup_window))
+  if (gtk_widget_get_mapped (completion->priv->popup_window))
     return;
 
-  if (!GTK_WIDGET_MAPPED (completion->priv->entry))
+  if (!gtk_widget_get_mapped (completion->priv->entry))
     return;
 
-  if (!GTK_WIDGET_HAS_FOCUS (completion->priv->entry))
+  if (!gtk_widget_has_focus (completion->priv->entry))
+    return;
+
+  if (completion->priv->grab_device)
     return;
 
   completion->priv->ignore_enter = TRUE;
@@ -1515,25 +1530,33 @@ _gtk_entry_completion_popup (GtkEntryCompletion *completion)
                          gtk_widget_get_screen (completion->priv->entry));
 
   gtk_widget_show (completion->priv->popup_window);
-    
-  gtk_grab_add (completion->priv->popup_window);
-  gdk_pointer_grab (completion->priv->popup_window->window, TRUE,
-                    GDK_BUTTON_PRESS_MASK |
-                    GDK_BUTTON_RELEASE_MASK |
-                    GDK_POINTER_MOTION_MASK,
-                    NULL, NULL, GDK_CURRENT_TIME);
+
+  gtk_device_grab_add (completion->priv->popup_window, device, TRUE);
+  gdk_device_grab (device, completion->priv->popup_window->window,
+                   GDK_OWNERSHIP_WINDOW, TRUE,
+                   GDK_BUTTON_PRESS_MASK |
+                   GDK_BUTTON_RELEASE_MASK |
+                   GDK_POINTER_MOTION_MASK,
+                   NULL, GDK_CURRENT_TIME);
+
+  completion->priv->grab_device = device;
 }
 
 void
 _gtk_entry_completion_popdown (GtkEntryCompletion *completion)
 {
-  if (!GTK_WIDGET_MAPPED (completion->priv->popup_window))
+  if (!gtk_widget_get_mapped (completion->priv->popup_window))
     return;
 
   completion->priv->ignore_enter = FALSE;
-  
-  gdk_pointer_ungrab (GDK_CURRENT_TIME);
-  gtk_grab_remove (completion->priv->popup_window);
+
+  if (completion->priv->grab_device)
+    {
+      gdk_device_ungrab (completion->priv->grab_device, GDK_CURRENT_TIME);
+      gtk_device_grab_remove (completion->priv->popup_window,
+                              completion->priv->grab_device);
+      completion->priv->grab_device = NULL;
+    }
 
   gtk_widget_hide (completion->priv->popup_window);
 }
@@ -1989,6 +2012,3 @@ gtk_entry_completion_get_inline_selection (GtkEntryCompletion *completion)
 
   return completion->priv->inline_selection;
 }
-
-#define __GTK_ENTRY_COMPLETION_C__
-#include "gtkaliasdef.c"
